==> scorchful-0.15.5%2B1.21.4-sources.jar: com/github/thedeathlycow/scorchful/entity/model/SunHatModel.java <==
package com.github.thedeathlycow.scorchful.entity.model;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_10034;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_572;
import net.minecraft.class_6230;
import net.minecraft.class_630;
import net.minecraft.client.model.*;

@Environment(EnvType.CLIENT)
public class SunHatModel<S extends class_10034> extends class_572<S> {

    public SunHatModel(class_630 root) {
        super(root);
    }

    public static class_5607 getTexturedModelData() {
        class_5605 dilation = class_5605.field_27715;
        class_5609 modelData = class_572.method_32011(dilation, 0.0f);
        class_5610 root = modelData.method_32111();
        root.method_32117(
                class_6230.field_32606,
                class_5606.method_32108()
                        .method_32101(0, 0)
                        .method_32098(
                                -8.0F, -4.5F, -8.0F,
                                16.0F, 0.0F, 16.0F,
                                dilation.method_32095(0.1f, 0f, 0.1f)
                        )
                        .method_32101(0, 16)
                        .method_32098(
                                -4.0F, -9.0F, -4.0F,
                                8.0F, 4.0F, 8.0F,
                                dilation.method_32094(0.6f)
                        ),
                class_5603.method_32090(0.0F, 24.0F, 0.0F)
        );

        return class_5607.method_32110(modelData, 64, 64);
    }

    public final void renderHead(class_4587 matrices, class_4588 vertices, int light, int overlay, int color) {
        this.method_2838().method_22699(matrices, vertices, light, overlay, color);
    }
}

==> scorchful-0.15.8%2B1.21.1-sources.jar: com/github/thedeathlycow/scorchful/entity/model/SunHatModel.java <==
package com.github.thedeathlycow.scorchful.entity.model;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1309;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_572;
import net.minecraft.class_6230;
import net.minecraft.class_630;
import net.minecraft.client.model.*;

@Environment(EnvType.CLIENT)
public class SunHatModel<T extends class_1309> extends class_572<T> {

    public SunHatModel(class_630 root) {
        super(root);
    }

    public static class_5607 getTexturedModelData() {
        class_5605 dilation = class_5605.field_27715;
        class_5609 modelData = class_572.method_32011(dilation, 0.0f);
        class_5610 root = modelData.method_32111();
        root.method_32117(
                class_6230.field_32606,
                class_5606.method_32108()
                        .method_32101(0, 0)
                        .method_32098(
                                -8.0F, -4.5F, -8.0F,
                                16.0F, 0.0F, 16.0F,
                                dilation.method_32095(0.1f, 0f, 0.1f)
                        )
                        .method_32101(0, 16)
                        .method_32098(
                                -4.0F, -9.0F, -4.0F,
                                8.0F, 4.0F, 8.0F,
                                dilation.method_32094(0.6f)
                        ),
                class_5603.method_32090(0.0F, 24.0F, 0.0F)
        );

        return class_5607.method_32110(modelData, 64, 64);
    }

    @Override
    public void method_2828(class_4587 matrices, class_4588 vertices, int light, int overlay, int color) {
        this.field_3398.method_22699(matrices, vertices, light, overlay, color);
    }
}
